@@ -38,7 +38,7 @@ class MixpanelUnauthorizedError(MixpanelError):
     pass
 
 
-class MixpanelRequestFailedError(MixpanelError):
+class MixpanelPaymentRequiredError(MixpanelError):
     pass
 
 
@@ -64,12 +64,12 @@ ERROR_CODE_EXCEPTION_MAPPING = {
         "message": "Invalid authorization credentials."
     },
     402: {
-        "raise_exception": MixpanelRequestFailedError,
-        "message": "Request can not be processed."
+        "raise_exception": MixpanelPaymentRequiredError,
+        "message": "Your current plan does not allow API calls. Payment is required to complete the operation."
     },
     403: {
         "raise_exception": MixpanelForbiddenError,
-        "message": "User doesn't have permission to access the resource."
+        "message": "User does not have permission to access the resource."
     },
     404: {
         "raise_exception": MixpanelNotFoundError,
@@ -93,29 +93,37 @@ def raise_for_error(response):
         response_json = response.json()
     except Exception:
         response_json = {}
-    if response.status_code != 200:
-        if response_json.get('error'):
-            message = "HTTP-error-code: {}, Error: {}".format(
-                response.status_code, response_json.get('error'))
+    error_code = response.status_code
+    error_message = response_json.get(
+        "error", response_json.get(
+            "message", ERROR_CODE_EXCEPTION_MAPPING.get(
+                error_code, {}).get(
+                    "message", "Unknown Error")))
+
+    # if response text contains something unusual error of to_date then provide helper message of timezone mismatch
+    # E.g error: to_date cannot be later than today
+    if error_code == 400:
+        if "to_date" in response.text:
+            error_message += " Please validate the timezone with the MixPanel UI under project settings."
         else:
-            message = "HTTP-error-code: {}, Error: {}".format(
-                response.status_code,
-                response_json.get("message", ERROR_CODE_EXCEPTION_MAPPING.get(
-                    response.status_code, {})).get("message", "Unknown Error"))
-        if response.status_code == 400:
-            message = '{}(Please verify your credentials.)'.format(message)
-        exc = ERROR_CODE_EXCEPTION_MAPPING.get(
-            response.status_code, {}).get("raise_exception", MixpanelError)
-        raise exc(message) from None
+            error_message = '{}(Please verify your credentials.)'.format(error_message)
+
+    message = "HTTP-error-code: {}, Error: {}".format(error_code, error_message)
+
+    exc = ERROR_CODE_EXCEPTION_MAPPING.get(
+        error_code, {}).get("raise_exception", MixpanelError)
+    raise exc(message) from None
 
 
 class MixpanelClient(object):
     def __init__(self,
                  api_secret,
                  api_domain,
+                 request_timeout,
                  user_agent=None):
         self.__api_secret = api_secret
         self.__api_domain = api_domain
+        self.__request_timeout = request_timeout
         self.__user_agent = user_agent
         self.__session = requests.Session()
         self.__verified = False
@@ -147,7 +155,7 @@ class MixpanelClient(object):
         try:
             response = self.__session.get(
                 url=url,
-                timeout=REQUEST_TIMEOUT,
+                timeout=self.__request_timeout, # Request timeout parameter
                 headers=headers)
         except requests.exceptions.Timeout as err:
             LOGGER.error('TIMEOUT ERROR: %s',str(err))
@@ -183,7 +191,7 @@ class MixpanelClient(object):
                                               params=params,
                                               json=json,
                                               stream=stream,
-                                              timeout=REQUEST_TIMEOUT,
+                                              timeout=self.__request_timeout, # Request timeout parameter
                                               **kwargs)
 
             if response.status_code > 500:
