@@ -1,5 +1,6 @@
 from singer.catalog import Catalog, CatalogEntry, Schema
-from tap_mixpanel.schema import get_schemas, STREAMS
+from tap_mixpanel.schema import get_schemas
+from tap_mixpanel.streams import STREAMS
 
 def discover(client, properties_flag):
     schemas, field_metadata = get_schemas(client, properties_flag)
@@ -12,7 +13,7 @@ def discover(client, properties_flag):
         catalog.streams.append(CatalogEntry(
             stream=stream_name,
             tap_stream_id=stream_name,
-            key_properties=STREAMS[stream_name]['key_properties'],
+            key_properties=STREAMS[stream_name].key_properties,
             schema=schema,
             metadata=mdata
         ))
